@@ -1,5 +1,6 @@
 from .scale import midi_scale, map_to_midi_scale
 from .chord import midi_chord
+from .arp import midi_arp
 from .utils import (
     note_to_freq,
     note_to_midi,
@@ -11,4 +12,5 @@ from .utils import (
     freq_to_octave,
     sharp_to_flat,
 )
+from .adsr import ADSR
 from .constants import *
